==> types_boto3_storagegateway-1.35.71-py3-none-any.whl: types_boto3_storagegateway/paginator.py <==
"""
Type annotations for storagegateway service client paginators.

[Open documentation](https://youtype.github.io/types_boto3_docs/types_boto3_storagegateway/paginators/)

Usage::

    ```python
    from boto3.session import Session

    from types_boto3_storagegateway.client import StorageGatewayClient
    from types_boto3_storagegateway.paginator import (
        DescribeTapeArchivesPaginator,
        DescribeTapeRecoveryPointsPaginator,
        DescribeTapesPaginator,
        DescribeVTLDevicesPaginator,
        ListFileSharesPaginator,
        ListFileSystemAssociationsPaginator,
        ListGatewaysPaginator,
        ListTagsForResourcePaginator,
        ListTapePoolsPaginator,
        ListTapesPaginator,
        ListVolumesPaginator,
    )

    session = Session()
    client: StorageGatewayClient = session.client("storagegateway")

    describe_tape_archives_paginator: DescribeTapeArchivesPaginator = client.get_paginator("describe_tape_archives")
    describe_tape_recovery_points_paginator: DescribeTapeRecoveryPointsPaginator = client.get_paginator("describe_tape_recovery_points")
    describe_tapes_paginator: DescribeTapesPaginator = client.get_paginator("describe_tapes")
    describe_vtl_devices_paginator: DescribeVTLDevicesPaginator = client.get_paginator("describe_vtl_devices")
    list_file_shares_paginator: ListFileSharesPaginator = client.get_paginator("list_file_shares")
    list_file_system_associations_paginator: ListFileSystemAssociationsPaginator = client.get_paginator("list_file_system_associations")
    list_gateways_paginator: ListGatewaysPaginator = client.get_paginator("list_gateways")
    list_tags_for_resource_paginator: ListTagsForResourcePaginator = client.get_paginator("list_tags_for_resource")
    list_tape_pools_paginator: ListTapePoolsPaginator = client.get_paginator("list_tape_pools")
    list_tapes_paginator: ListTapesPaginator = client.get_paginator("list_tapes")
    list_volumes_paginator: ListVolumesPaginator = client.get_paginator("list_volumes")
    ```

Copyright 2024 Vlad Emelianov
"""

import sys
from typing import Generic, Iterator, TypeVar

from botocore.paginate import PageIterator, Paginator

from .type_defs import (
    DescribeTapeArchivesInputDescribeTapeArchivesPaginateTypeDef,
    DescribeTapeArchivesOutputTypeDef,
    DescribeTapeRecoveryPointsInputDescribeTapeRecoveryPointsPaginateTypeDef,
    DescribeTapeRecoveryPointsOutputTypeDef,
    DescribeTapesInputDescribeTapesPaginateTypeDef,
    DescribeTapesOutputTypeDef,
    DescribeVTLDevicesInputDescribeVTLDevicesPaginateTypeDef,
    DescribeVTLDevicesOutputTypeDef,
    ListFileSharesInputListFileSharesPaginateTypeDef,
    ListFileSharesOutputTypeDef,
    ListFileSystemAssociationsInputListFileSystemAssociationsPaginateTypeDef,
    ListFileSystemAssociationsOutputTypeDef,
    ListGatewaysInputListGatewaysPaginateTypeDef,
    ListGatewaysOutputTypeDef,
    ListTagsForResourceInputListTagsForResourcePaginateTypeDef,
    ListTagsForResourceOutputTypeDef,
    ListTapePoolsInputListTapePoolsPaginateTypeDef,
    ListTapePoolsOutputTypeDef,
    ListTapesInputListTapesPaginateTypeDef,
    ListTapesOutputTypeDef,
    ListVolumesInputListVolumesPaginateTypeDef,
    ListVolumesOutputTypeDef,
)

if sys.version_info >= (3, 12):
    from typing import Unpack
else:
    from typing_extensions import Unpack


__all__ = (
    "DescribeTapeArchivesPaginator",
    "DescribeTapeRecoveryPointsPaginator",
    "DescribeTapesPaginator",
    "DescribeVTLDevicesPaginator",
    "ListFileSharesPaginator",
    "ListFileSystemAssociationsPaginator",
    "ListGatewaysPaginator",
    "ListTagsForResourcePaginator",
    "ListTapePoolsPaginator",
    "ListTapesPaginator",
    "ListVolumesPaginator",
)


_ItemTypeDef = TypeVar("_ItemTypeDef")


class _PageIterator(PageIterator, Generic[_ItemTypeDef]):
    def __iter__(self) -> Iterator[_ItemTypeDef]:
        """
        Proxy method to specify iterator item type.
        """


class DescribeTapeArchivesPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/storagegateway/paginator/DescribeTapeArchives.html#StorageGateway.Paginator.DescribeTapeArchives)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_storagegateway/paginators/#describetapearchivespaginator)
    """

    def paginate(
        self, **kwargs: Unpack[DescribeTapeArchivesInputDescribeTapeArchivesPaginateTypeDef]
    ) -> _PageIterator[DescribeTapeArchivesOutputTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/storagegateway/paginator/DescribeTapeArchives.html#StorageGateway.Paginator.DescribeTapeArchives.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_storagegateway/paginators/#describetapearchivespaginator)
        """


class DescribeTapeRecoveryPointsPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/storagegateway/paginator/DescribeTapeRecoveryPoints.html#StorageGateway.Paginator.DescribeTapeRecoveryPoints)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_storagegateway/paginators/#describetaperecoverypointspaginator)
    """

    def paginate(
        self,
        **kwargs: Unpack[DescribeTapeRecoveryPointsInputDescribeTapeRecoveryPointsPaginateTypeDef],
    ) -> _PageIterator[DescribeTapeRecoveryPointsOutputTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/storagegateway/paginator/DescribeTapeRecoveryPoints.html#StorageGateway.Paginator.DescribeTapeRecoveryPoints.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_storagegateway/paginators/#describetaperecoverypointspaginator)
        """


class DescribeTapesPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/storagegateway/paginator/DescribeTapes.html#StorageGateway.Paginator.DescribeTapes)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_storagegateway/paginators/#describetapespaginator)
    """

    def paginate(
        self, **kwargs: Unpack[DescribeTapesInputDescribeTapesPaginateTypeDef]
    ) -> _PageIterator[DescribeTapesOutputTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/storagegateway/paginator/DescribeTapes.html#StorageGateway.Paginator.DescribeTapes.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_storagegateway/paginators/#describetapespaginator)
        """


class DescribeVTLDevicesPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/storagegateway/paginator/DescribeVTLDevices.html#StorageGateway.Paginator.DescribeVTLDevices)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_storagegateway/paginators/#describevtldevicespaginator)
    """

    def paginate(
        self, **kwargs: Unpack[DescribeVTLDevicesInputDescribeVTLDevicesPaginateTypeDef]
    ) -> _PageIterator[DescribeVTLDevicesOutputTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/storagegateway/paginator/DescribeVTLDevices.html#StorageGateway.Paginator.DescribeVTLDevices.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_storagegateway/paginators/#describevtldevicespaginator)
        """


class ListFileSharesPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/storagegateway/paginator/ListFileShares.html#StorageGateway.Paginator.ListFileShares)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_storagegateway/paginators/#listfilesharespaginator)
    """

    def paginate(
        self, **kwargs: Unpack[ListFileSharesInputListFileSharesPaginateTypeDef]
    ) -> _PageIterator[ListFileSharesOutputTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/storagegateway/paginator/ListFileShares.html#StorageGateway.Paginator.ListFileShares.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_storagegateway/paginators/#listfilesharespaginator)
        """


class ListFileSystemAssociationsPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/storagegateway/paginator/ListFileSystemAssociations.html#StorageGateway.Paginator.ListFileSystemAssociations)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_storagegateway/paginators/#listfilesystemassociationspaginator)
    """

    def paginate(
        self,
        **kwargs: Unpack[ListFileSystemAssociationsInputListFileSystemAssociationsPaginateTypeDef],
    ) -> _PageIterator[ListFileSystemAssociationsOutputTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/storagegateway/paginator/ListFileSystemAssociations.html#StorageGateway.Paginator.ListFileSystemAssociations.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_storagegateway/paginators/#listfilesystemassociationspaginator)
        """


class ListGatewaysPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/storagegateway/paginator/ListGateways.html#StorageGateway.Paginator.ListGateways)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_storagegateway/paginators/#listgatewayspaginator)
    """

    def paginate(
        self, **kwargs: Unpack[ListGatewaysInputListGatewaysPaginateTypeDef]
    ) -> _PageIterator[ListGatewaysOutputTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/storagegateway/paginator/ListGateways.html#StorageGateway.Paginator.ListGateways.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_storagegateway/paginators/#listgatewayspaginator)
        """


class ListTagsForResourcePaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/storagegateway/paginator/ListTagsForResource.html#StorageGateway.Paginator.ListTagsForResource)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_storagegateway/paginators/#listtagsforresourcepaginator)
    """

    def paginate(
        self, **kwargs: Unpack[ListTagsForResourceInputListTagsForResourcePaginateTypeDef]
    ) -> _PageIterator[ListTagsForResourceOutputTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/storagegateway/paginator/ListTagsForResource.html#StorageGateway.Paginator.ListTagsForResource.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_storagegateway/paginators/#listtagsforresourcepaginator)
        """


class ListTapePoolsPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/storagegateway/paginator/ListTapePools.html#StorageGateway.Paginator.ListTapePools)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_storagegateway/paginators/#listtapepoolspaginator)
    """

    def paginate(
        self, **kwargs: Unpack[ListTapePoolsInputListTapePoolsPaginateTypeDef]
    ) -> _PageIterator[ListTapePoolsOutputTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/storagegateway/paginator/ListTapePools.html#StorageGateway.Paginator.ListTapePools.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_storagegateway/paginators/#listtapepoolspaginator)
        """


class ListTapesPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/storagegateway/paginator/ListTapes.html#StorageGateway.Paginator.ListTapes)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_storagegateway/paginators/#listtapespaginator)
    """

    def paginate(
        self, **kwargs: Unpack[ListTapesInputListTapesPaginateTypeDef]
    ) -> _PageIterator[ListTapesOutputTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/storagegateway/paginator/ListTapes.html#StorageGateway.Paginator.ListTapes.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_storagegateway/paginators/#listtapespaginator)
        """


class ListVolumesPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/storagegateway/paginator/ListVolumes.html#StorageGateway.Paginator.ListVolumes)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_storagegateway/paginators/#listvolumespaginator)
    """

    def paginate(
        self, **kwargs: Unpack[ListVolumesInputListVolumesPaginateTypeDef]
    ) -> _PageIterator[ListVolumesOutputTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/storagegateway/paginator/ListVolumes.html#StorageGateway.Paginator.ListVolumes.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_storagegateway/paginators/#listvolumespaginator)
        """

==> types_boto3_storagegateway-1.36.0-py3-none-any.whl: types_boto3_storagegateway/paginator.py <==
"""
Type annotations for storagegateway service client paginators.

[Documentation](https://youtype.github.io/types_boto3_docs/types_boto3_storagegateway/paginators/)

Usage::

    ```python
    from boto3.session import Session

    from types_boto3_storagegateway.client import StorageGatewayClient
    from types_boto3_storagegateway.paginator import (
        DescribeTapeArchivesPaginator,
        DescribeTapeRecoveryPointsPaginator,
        DescribeTapesPaginator,
        DescribeVTLDevicesPaginator,
        ListFileSharesPaginator,
        ListFileSystemAssociationsPaginator,
        ListGatewaysPaginator,
        ListTagsForResourcePaginator,
        ListTapePoolsPaginator,
        ListTapesPaginator,
        ListVolumesPaginator,
    )

    session = Session()
    client: StorageGatewayClient = session.client("storagegateway")

    describe_tape_archives_paginator: DescribeTapeArchivesPaginator = client.get_paginator("describe_tape_archives")
    describe_tape_recovery_points_paginator: DescribeTapeRecoveryPointsPaginator = client.get_paginator("describe_tape_recovery_points")
    describe_tapes_paginator: DescribeTapesPaginator = client.get_paginator("describe_tapes")
    describe_vtl_devices_paginator: DescribeVTLDevicesPaginator = client.get_paginator("describe_vtl_devices")
    list_file_shares_paginator: ListFileSharesPaginator = client.get_paginator("list_file_shares")
    list_file_system_associations_paginator: ListFileSystemAssociationsPaginator = client.get_paginator("list_file_system_associations")
    list_gateways_paginator: ListGatewaysPaginator = client.get_paginator("list_gateways")
    list_tags_for_resource_paginator: ListTagsForResourcePaginator = client.get_paginator("list_tags_for_resource")
    list_tape_pools_paginator: ListTapePoolsPaginator = client.get_paginator("list_tape_pools")
    list_tapes_paginator: ListTapesPaginator = client.get_paginator("list_tapes")
    list_volumes_paginator: ListVolumesPaginator = client.get_paginator("list_volumes")
    ```

Copyright 2025 Vlad Emelianov
"""

from __future__ import annotations

import sys
from typing import TYPE_CHECKING

from botocore.paginate import PageIterator, Paginator

from .type_defs import (
    DescribeTapeArchivesInputPaginateTypeDef,
    DescribeTapeArchivesOutputTypeDef,
    DescribeTapeRecoveryPointsInputPaginateTypeDef,
    DescribeTapeRecoveryPointsOutputTypeDef,
    DescribeTapesInputPaginateTypeDef,
    DescribeTapesOutputTypeDef,
    DescribeVTLDevicesInputPaginateTypeDef,
    DescribeVTLDevicesOutputTypeDef,
    ListFileSharesInputPaginateTypeDef,
    ListFileSharesOutputTypeDef,
    ListFileSystemAssociationsInputPaginateTypeDef,
    ListFileSystemAssociationsOutputTypeDef,
    ListGatewaysInputPaginateTypeDef,
    ListGatewaysOutputTypeDef,
    ListTagsForResourceInputPaginateTypeDef,
    ListTagsForResourceOutputTypeDef,
    ListTapePoolsInputPaginateTypeDef,
    ListTapePoolsOutputTypeDef,
    ListTapesInputPaginateTypeDef,
    ListTapesOutputTypeDef,
    ListVolumesInputPaginateTypeDef,
    ListVolumesOutputTypeDef,
)

if sys.version_info >= (3, 12):
    from typing import Unpack
else:
    from typing_extensions import Unpack


__all__ = (
    "DescribeTapeArchivesPaginator",
    "DescribeTapeRecoveryPointsPaginator",
    "DescribeTapesPaginator",
    "DescribeVTLDevicesPaginator",
    "ListFileSharesPaginator",
    "ListFileSystemAssociationsPaginator",
    "ListGatewaysPaginator",
    "ListTagsForResourcePaginator",
    "ListTapePoolsPaginator",
    "ListTapesPaginator",
    "ListVolumesPaginator",
)


if TYPE_CHECKING:
    _DescribeTapeArchivesPaginatorBase = Paginator[DescribeTapeArchivesOutputTypeDef]
else:
    _DescribeTapeArchivesPaginatorBase = Paginator  # type: ignore[assignment]


class DescribeTapeArchivesPaginator(_DescribeTapeArchivesPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/storagegateway/paginator/DescribeTapeArchives.html#StorageGateway.Paginator.DescribeTapeArchives)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_storagegateway/paginators/#describetapearchivespaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[DescribeTapeArchivesInputPaginateTypeDef]
    ) -> PageIterator[DescribeTapeArchivesOutputTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/storagegateway/paginator/DescribeTapeArchives.html#StorageGateway.Paginator.DescribeTapeArchives.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_storagegateway/paginators/#describetapearchivespaginator)
        """


if TYPE_CHECKING:
    _DescribeTapeRecoveryPointsPaginatorBase = Paginator[DescribeTapeRecoveryPointsOutputTypeDef]
else:
    _DescribeTapeRecoveryPointsPaginatorBase = Paginator  # type: ignore[assignment]


class DescribeTapeRecoveryPointsPaginator(_DescribeTapeRecoveryPointsPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/storagegateway/paginator/DescribeTapeRecoveryPoints.html#StorageGateway.Paginator.DescribeTapeRecoveryPoints)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_storagegateway/paginators/#describetaperecoverypointspaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[DescribeTapeRecoveryPointsInputPaginateTypeDef]
    ) -> PageIterator[DescribeTapeRecoveryPointsOutputTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/storagegateway/paginator/DescribeTapeRecoveryPoints.html#StorageGateway.Paginator.DescribeTapeRecoveryPoints.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_storagegateway/paginators/#describetaperecoverypointspaginator)
        """


if TYPE_CHECKING:
    _DescribeTapesPaginatorBase = Paginator[DescribeTapesOutputTypeDef]
else:
    _DescribeTapesPaginatorBase = Paginator  # type: ignore[assignment]


class DescribeTapesPaginator(_DescribeTapesPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/storagegateway/paginator/DescribeTapes.html#StorageGateway.Paginator.DescribeTapes)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_storagegateway/paginators/#describetapespaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[DescribeTapesInputPaginateTypeDef]
    ) -> PageIterator[DescribeTapesOutputTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/storagegateway/paginator/DescribeTapes.html#StorageGateway.Paginator.DescribeTapes.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_storagegateway/paginators/#describetapespaginator)
        """


if TYPE_CHECKING:
    _DescribeVTLDevicesPaginatorBase = Paginator[DescribeVTLDevicesOutputTypeDef]
else:
    _DescribeVTLDevicesPaginatorBase = Paginator  # type: ignore[assignment]


class DescribeVTLDevicesPaginator(_DescribeVTLDevicesPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/storagegateway/paginator/DescribeVTLDevices.html#StorageGateway.Paginator.DescribeVTLDevices)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_storagegateway/paginators/#describevtldevicespaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[DescribeVTLDevicesInputPaginateTypeDef]
    ) -> PageIterator[DescribeVTLDevicesOutputTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/storagegateway/paginator/DescribeVTLDevices.html#StorageGateway.Paginator.DescribeVTLDevices.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_storagegateway/paginators/#describevtldevicespaginator)
        """


if TYPE_CHECKING:
    _ListFileSharesPaginatorBase = Paginator[ListFileSharesOutputTypeDef]
else:
    _ListFileSharesPaginatorBase = Paginator  # type: ignore[assignment]


class ListFileSharesPaginator(_ListFileSharesPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/storagegateway/paginator/ListFileShares.html#StorageGateway.Paginator.ListFileShares)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_storagegateway/paginators/#listfilesharespaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListFileSharesInputPaginateTypeDef]
    ) -> PageIterator[ListFileSharesOutputTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/storagegateway/paginator/ListFileShares.html#StorageGateway.Paginator.ListFileShares.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_storagegateway/paginators/#listfilesharespaginator)
        """


if TYPE_CHECKING:
    _ListFileSystemAssociationsPaginatorBase = Paginator[ListFileSystemAssociationsOutputTypeDef]
else:
    _ListFileSystemAssociationsPaginatorBase = Paginator  # type: ignore[assignment]


class ListFileSystemAssociationsPaginator(_ListFileSystemAssociationsPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/storagegateway/paginator/ListFileSystemAssociations.html#StorageGateway.Paginator.ListFileSystemAssociations)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_storagegateway/paginators/#listfilesystemassociationspaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListFileSystemAssociationsInputPaginateTypeDef]
    ) -> PageIterator[ListFileSystemAssociationsOutputTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/storagegateway/paginator/ListFileSystemAssociations.html#StorageGateway.Paginator.ListFileSystemAssociations.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_storagegateway/paginators/#listfilesystemassociationspaginator)
        """


if TYPE_CHECKING:
    _ListGatewaysPaginatorBase = Paginator[ListGatewaysOutputTypeDef]
else:
    _ListGatewaysPaginatorBase = Paginator  # type: ignore[assignment]


class ListGatewaysPaginator(_ListGatewaysPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/storagegateway/paginator/ListGateways.html#StorageGateway.Paginator.ListGateways)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_storagegateway/paginators/#listgatewayspaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListGatewaysInputPaginateTypeDef]
    ) -> PageIterator[ListGatewaysOutputTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/storagegateway/paginator/ListGateways.html#StorageGateway.Paginator.ListGateways.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_storagegateway/paginators/#listgatewayspaginator)
        """


if TYPE_CHECKING:
    _ListTagsForResourcePaginatorBase = Paginator[ListTagsForResourceOutputTypeDef]
else:
    _ListTagsForResourcePaginatorBase = Paginator  # type: ignore[assignment]


class ListTagsForResourcePaginator(_ListTagsForResourcePaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/storagegateway/paginator/ListTagsForResource.html#StorageGateway.Paginator.ListTagsForResource)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_storagegateway/paginators/#listtagsforresourcepaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListTagsForResourceInputPaginateTypeDef]
    ) -> PageIterator[ListTagsForResourceOutputTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/storagegateway/paginator/ListTagsForResource.html#StorageGateway.Paginator.ListTagsForResource.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_storagegateway/paginators/#listtagsforresourcepaginator)
        """


if TYPE_CHECKING:
    _ListTapePoolsPaginatorBase = Paginator[ListTapePoolsOutputTypeDef]
else:
    _ListTapePoolsPaginatorBase = Paginator  # type: ignore[assignment]


class ListTapePoolsPaginator(_ListTapePoolsPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/storagegateway/paginator/ListTapePools.html#StorageGateway.Paginator.ListTapePools)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_storagegateway/paginators/#listtapepoolspaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListTapePoolsInputPaginateTypeDef]
    ) -> PageIterator[ListTapePoolsOutputTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/storagegateway/paginator/ListTapePools.html#StorageGateway.Paginator.ListTapePools.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_storagegateway/paginators/#listtapepoolspaginator)
        """


if TYPE_CHECKING:
    _ListTapesPaginatorBase = Paginator[ListTapesOutputTypeDef]
else:
    _ListTapesPaginatorBase = Paginator  # type: ignore[assignment]


class ListTapesPaginator(_ListTapesPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/storagegateway/paginator/ListTapes.html#StorageGateway.Paginator.ListTapes)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_storagegateway/paginators/#listtapespaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListTapesInputPaginateTypeDef]
    ) -> PageIterator[ListTapesOutputTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/storagegateway/paginator/ListTapes.html#StorageGateway.Paginator.ListTapes.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_storagegateway/paginators/#listtapespaginator)
        """


if TYPE_CHECKING:
    _ListVolumesPaginatorBase = Paginator[ListVolumesOutputTypeDef]
else:
    _ListVolumesPaginatorBase = Paginator  # type: ignore[assignment]


class ListVolumesPaginator(_ListVolumesPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/storagegateway/paginator/ListVolumes.html#StorageGateway.Paginator.ListVolumes)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_storagegateway/paginators/#listvolumespaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListVolumesInputPaginateTypeDef]
    ) -> PageIterator[ListVolumesOutputTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/storagegateway/paginator/ListVolumes.html#StorageGateway.Paginator.ListVolumes.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_storagegateway/paginators/#listvolumespaginator)
        """
